@@ -1,6 +1,4 @@
 /*
- * $XConsortium: saver.c,v 1.12 94/04/17 20:59:36 dpw Exp $
- *
 Copyright (c) 1992  X Consortium
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,7 +25,53 @@ in this Software without prior written authorization from the X Consortium.
  * Author:  Keith Packard, MIT X Consortium
  */
 
-/* $XFree86: xc/programs/Xserver/Xext/saver.c,v 3.8 2003/11/17 22:20:26 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/Xext/saver.c,v 3.11 2004/10/23 01:28:38 dawes Exp $ */
+/*
+ * Copyright (c) 1994-2004 by The XFree86 Project, Inc.
+ * All rights reserved.
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining
+ * a copy of this software and associated documentation files (the
+ * "Software"), to deal in the Software without restriction, including
+ * without limitation the rights to use, copy, modify, merge, publish,
+ * distribute, sublicense, and/or sell copies of the Software, and to
+ * permit persons to whom the Software is furnished to do so, subject
+ * to the following conditions:
+ *
+ *   1.  Redistributions of source code must retain the above copyright
+ *       notice, this list of conditions, and the following disclaimer.
+ *
+ *   2.  Redistributions in binary form must reproduce the above copyright
+ *       notice, this list of conditions and the following disclaimer
+ *       in the documentation and/or other materials provided with the
+ *       distribution, and in the same place and form as other copyright,
+ *       license and disclaimer information.
+ *
+ *   3.  The end-user documentation included with the redistribution,
+ *       if any, must include the following acknowledgment: "This product
+ *       includes software developed by The XFree86 Project, Inc
+ *       (http://www.xfree86.org/) and its contributors", in the same
+ *       place and form as other third-party acknowledgments.  Alternately,
+ *       this acknowledgment may appear in the software itself, in the
+ *       same form and location as other such third-party acknowledgments.
+ *
+ *   4.  Except as contained in this notice, the name of The XFree86
+ *       Project, Inc shall not be used in advertising or otherwise to
+ *       promote the sale, use or other dealings in this Software without
+ *       prior written authorization from The XFree86 Project, Inc.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
+ * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE XFREE86 PROJECT, INC OR ITS CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
+ * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
+ * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+ * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
+ * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
+ * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
 
 #define NEED_REPLIES
 #define NEED_EVENTS
@@ -810,7 +854,7 @@ ScreenSaverSetAttributes (ClientPtr client)
     DepthPtr			pDepth;
     WindowOptPtr		ancwopt;
     unsigned long		*pVlist;
-    unsigned long		*values = 0;
+    unsigned long		*values = 0, *save = 0;
     unsigned long		tmask, imask;
     unsigned long		val;
     Pixmap			pixID;
@@ -938,6 +982,7 @@ ScreenSaverSetAttributes (ClientPtr client)
 	ret = BadAlloc;
 	goto bail;
     }
+    save = values;
     pAttr->screen = pScreen;
     pAttr->client = client;
     pAttr->x = stuff->x;
@@ -1155,7 +1200,7 @@ ScreenSaverSetAttributes (ClientPtr client)
 	pVlist++;
     }
     if (pPriv->attr)
-	FreeScreenAttr (pPriv->attr);
+	FreeResource(pPriv->attr->resource, AttrType);
     pPriv->attr = pAttr;
     pAttr->resource = FakeClientID (client->index);
     if (!AddResource (pAttr->resource, AttrType, (pointer) pAttr))
@@ -1166,7 +1211,7 @@ PatchUp:
 bail:
     CheckScreenPrivate (pScreen);
     xfree (pAttr);
-    xfree (values);
+    xfree (save);
     return ret;
 }
 
@@ -1184,7 +1229,7 @@ ScreenSaverUnsetAttributes (ClientPtr client)
     pPriv = GetScreenPrivate (pDraw->pScreen);
     if (pPriv && pPriv->attr && pPriv->attr->client == client)
     {
-    	FreeScreenAttr (pPriv->attr);
+	FreeResource(pPriv->attr->resource, AttrType);
 	pPriv->attr = NULL;
 	CheckScreenPrivate (pDraw->pScreen);
     }
