@@ -1,6 +1,6 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Option.c,v 1.30 2004/02/13 23:58:38 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Option.c,v 1.36 2005/02/18 01:52:59 dawes Exp $ */
 /*
- * Copyright (c) 1998-2003 by The XFree86 Project, Inc.
+ * Copyright (c) 1998-2005 by The XFree86 Project, Inc.
  * All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -45,6 +45,50 @@
  * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+/*
+ * Copyright  2003, 2004, 2005 David H. Dawes.
+ * Copyright  2003, 2004, 2005 X-Oz Technologies.
+ * All rights reserved.
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ * 
+ *  1. Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions, and the following disclaimer.
+ *
+ *  2. Redistributions in binary form must reproduce the above
+ *     copyright notice, this list of conditions and the following
+ *     disclaimer in the documentation and/or other materials provided
+ *     with the distribution.
+ * 
+ *  3. The end-user documentation included with the redistribution,
+ *     if any, must include the following acknowledgment: "This product
+ *     includes software developed by X-Oz Technologies
+ *     (http://www.x-oz.com/)."  Alternately, this acknowledgment may
+ *     appear in the software itself, if and wherever such third-party
+ *     acknowledgments normally appear.
+ *
+ *  4. Except as contained in this notice, the name of X-Oz
+ *     Technologies shall not be used in advertising or otherwise to
+ *     promote the sale, use or other dealings in this Software without
+ *     prior written authorization from X-Oz Technologies.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL X-OZ TECHNOLOGIES OR ITS CONTRIBUTORS
+ * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
+ * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
+ * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+ * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
+ * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
+ * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
 
 /*
  * Author: David Dawes <dawes@xfree86.org>
@@ -306,17 +350,25 @@ xf86CheckBoolOption(pointer optlist, const char *name, int deflt)
 pointer
 xf86ReplaceIntOption(pointer optlist, const char *name, const int val)
 {
-    char *tmp = xnfalloc(16);
-    sprintf(tmp,"%i",val);
-    return xf86AddNewOption(optlist,name,tmp);
+    char *tmp;
+
+    xasprintf(&tmp, "%i", val);
+    if (tmp)
+	return xf86AddNewOption(optlist, name, tmp);
+    else
+	return NULL;
 }
 
 pointer
 xf86ReplaceRealOption(pointer optlist, const char *name, const double val)
 {
-    char *tmp = xnfalloc(32);
-    snprintf(tmp,32,"%f",val);
-    return xf86AddNewOption(optlist,name,tmp);
+    char *tmp;
+
+    xasprintf(&tmp, "%f", val);
+    if (tmp)
+	return xf86AddNewOption(optlist, name, tmp);
+    else
+	return NULL;
 }
 
 pointer
@@ -367,6 +419,12 @@ xf86OptionListMerge(pointer head, pointer tail)
 	return xf86optionListMerge(head, tail);
 }
 
+pointer
+xf86OptionListDup(pointer opt)
+{
+	return xf86optionListDup(opt);
+}
+
 void
 xf86OptionListFree(pointer opt)
 {
@@ -400,7 +458,24 @@ xf86OptionListReport(pointer parm)
     }
 }
 
-/* End of XInput-caused section	*/
+void
+xf86OptionListPrint(int verb, MessageType from, const char *prefix,
+		    pointer parm)
+{
+    XF86OptionPtr opts = parm;
+    const char *p;
+
+    p = EMPTYIFNULL(prefix);
+    while (opts) {
+	if (xf86optionValue(opts))
+	    xf86MsgVerb(from, verb, "%sOption \"%s\" \"%s\"\n", p,
+			xf86optionName(opts), xf86optionValue(opts));
+	else
+	    xf86MsgVerb(from, verb, "%sOption \"%s\"\n", p,
+			xf86optionName(opts));
+	opts = xf86nextOption(opts);
+    }
+}
 
 pointer
 xf86FindOption(pointer options, const char *name)
@@ -456,19 +531,25 @@ xf86CheckIfOptionUsedByName(pointer options, const char *name)
 }
 
 void
-xf86ShowUnusedOptions(int scrnIndex, pointer options)
+xf86ShowUnusedOptionsVerb(int scrnIndex, pointer options, int verb)
 {
     XF86OptionPtr opt = options;
 
     while (opt) {
 	if (opt->opt_name && !opt->opt_used) {
-	    xf86DrvMsg(scrnIndex, X_WARNING, "Option \"%s\" is not used\n",
-			opt->opt_name);
+	    xf86DrvMsgVerb(scrnIndex, X_WARNING, verb,
+			   "Option \"%s\" is not used\n", opt->opt_name);
 	}
 	opt = opt->list.next;
     }
 }
 
+void
+xf86ShowUnusedOptions(int scrnIndex, pointer options)
+{
+    xf86ShowUnusedOptionsVerb(scrnIndex, options, X_LOG_DEFAULT_VERB);
+}
+
 
 static Bool
 GetBoolValue(OptionInfoPtr p, const char *s)
@@ -532,7 +613,7 @@ ParseOptionValue(int scrnIndex, pointer options, OptionInfoPtr p,
 	case OPTV_STRING:
 	    if (*s == '\0') {
 		xf86DrvMsg(scrnIndex, X_WARNING,
-			   "Option \"%s\" requires an string value\n",
+			   "Option \"%s\" requires a string value\n",
 			   p->name);
 		p->found = FALSE;
 	    } else {
@@ -881,7 +962,7 @@ xf86NormalizeName(const char *s)
     if (s == NULL)
 	return NULL;
 
-    ret = xalloc(strlen(s) + 1);
+    ret = xnfalloc(strlen(s) + 1);
     for (p = s, q = ret; *p != 0; p++) {
 	switch (*p) {
 	case '_':
