@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/os/WaitFor.c,v 3.44 2004/02/17 15:30:26 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/os/WaitFor.c,v 3.47 2004/06/23 19:40:17 tsi Exp $ */
 /***********************************************************
 
 Copyright 1987, 1998  The Open Group
@@ -46,6 +46,53 @@ SOFTWARE.
 
 ******************************************************************/
 
+/*
+ * Portions Copyright (c) 1994-2004 by The XFree86 Project, Inc.
+ * All rights reserved.
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining
+ * a copy of this software and associated documentation files (the
+ * "Software"), to deal in the Software without restriction, including
+ * without limitation the rights to use, copy, modify, merge, publish,
+ * distribute, sublicense, and/or sell copies of the Software, and to
+ * permit persons to whom the Software is furnished to do so, subject
+ * to the following conditions:
+ *
+ *   1.  Redistributions of source code must retain the above copyright
+ *       notice, this list of conditions, and the following disclaimer.
+ *
+ *   2.  Redistributions in binary form must reproduce the above copyright
+ *       notice, this list of conditions and the following disclaimer
+ *       in the documentation and/or other materials provided with the
+ *       distribution, and in the same place and form as other copyright,
+ *       license and disclaimer information.
+ *
+ *   3.  The end-user documentation included with the redistribution,
+ *       if any, must include the following acknowledgment: "This product
+ *       includes software developed by The XFree86 Project, Inc
+ *       (http://www.xfree86.org/) and its contributors", in the same
+ *       place and form as other third-party acknowledgments.  Alternately,
+ *       this acknowledgment may appear in the software itself, in the
+ *       same form and location as other such third-party acknowledgments.
+ *
+ *   4.  Except as contained in this notice, the name of The XFree86
+ *       Project, Inc shall not be used in advertising or otherwise to
+ *       promote the sale, use or other dealings in this Software without
+ *       prior written authorization from The XFree86 Project, Inc.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
+ * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE XFREE86 PROJECT, INC OR ITS CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
+ * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
+ * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+ * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
+ * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
+ * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
 /* $Xorg: WaitFor.c,v 1.4 2001/02/09 02:05:22 xorgcvs Exp $ */
 
 /*****************************************************************
@@ -342,22 +389,32 @@ WaitForSomething(int *pClientsReady)
 #ifndef WIN32
 	for (i=0; i<howmany(XFD_SETSIZE, NFDBITS); i++)
 	{
+#ifdef XSYNC
 	    int highest_priority = 0;
+#endif
 
 	    while (clientsReadable.fds_bits[i])
 	    {
-	        int client_priority, client_index;
+	        int client_index;
+#ifdef XSYNC
+	        int client_priority;
+#endif
 
 		curclient = ffs (clientsReadable.fds_bits[i]) - 1;
 		client_index = /* raphael: modified */
 			ConnectionTranslation[curclient + (i * (sizeof(fd_mask) * 8))];
 #else
+#ifdef XSYNC
 	int highest_priority = 0;
+#endif
 	fd_set savedClientsReadable;
 	XFD_COPYSET(&clientsReadable, &savedClientsReadable);
 	for (i = 0; i < XFD_SETCOUNT(&savedClientsReadable); i++)
 	{
-	    int client_priority, client_index;
+	    int client_index;
+#ifdef XSYNC
+	    int client_priority;
+#endif
 
 	    curclient = XFD_FD(&savedClientsReadable, i);
 	    client_index = ConnectionTranslation[curclient];
@@ -404,22 +461,6 @@ WaitForSomething(int *pClientsReady)
     return nready;
 }
 
-#if 0
-/*
- * This is not always a macro.
- */
-ANYSET(FdMask *src)
-{
-    int i;
-
-    for (i=0; i<mskcnt; i++)
-	if (src[ i ])
-	    return (TRUE);
-    return (FALSE);
-}
-#endif
-
-
 static void
 DoTimer(OsTimerPtr timer, CARD32 now, OsTimerPtr *prev)
 {
@@ -666,14 +707,20 @@ SetDPMSTimers(void)
     if (DPMSStandbyTime > 0) {
         DPMSStandbyTimer = TimerSet(DPMSStandbyTimer, 0, DPMSStandbyTime,
                                     DPMSStandbyTimerExpire, NULL);
+    } else if (DPMSStandbyTimer) {
+	TimerCancel(DPMSStandbyTimer);
     }
     if (DPMSSuspendTime > 0) {
         DPMSSuspendTimer = TimerSet(DPMSSuspendTimer, 0, DPMSSuspendTime,
                                     DPMSSuspendTimerExpire, NULL);
+    } else if (DPMSSuspendTimer) {
+	TimerCancel(DPMSSuspendTimer);
     }
     if (DPMSOffTime > 0) {
         DPMSOffTimer = TimerSet(DPMSOffTimer, 0, DPMSOffTime,
                                 DPMSOffTimerExpire, NULL);
+    } else if (DPMSOffTimer) {
+	TimerCancel(DPMSOffTimer);
     }
 }
 #endif
